@@ -30,12 +30,9 @@ use num_traits::cast::FromPrimitive;
 pub fn start_server(mut engine: Engine) {
     let mut response: [u8; MUMBLE_LINK_SIZE + 2] = [0; MUMBLE_LINK_SIZE + 2];
     let mut request: [u8; 64] = [0; 64];
-    dbg!("server started and entering loop");
     loop {
         let (_, s) = engine.socket.recv_from(&mut request).unwrap();
-        dbg!("received stuff.", request);
         respond_to_request(&mut engine, &request, &mut response, s);
-        dbg!("sent stuff", response[0]);
     }
 }
 /// parses request, prepares response to store it.
